@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Mouse;
 use Path::Class;
@@ -145,8 +145,8 @@ Parse::Crontab - Perl extension to parse Vixie crontab file
 
     use Parse::Crontab;
     my $crontab = Parse::Crontab->new(file => 'crontab.txt');
-    if ($crontab->is_valid) {
-        warn $crontab->error_message;
+    unless ($crontab->is_valid) {
+        warn $crontab->error_messages;
     }
     for my $job ($crontab->jobs) {
         say $job->minute;
